@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
 our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -196,6 +196,7 @@ _
             'summary.alt.plurality.singular' => 'Include an extra module',
             schema => ['array*', of=>'str*'],
             'x.schema.element_entity' => 'modulename',
+            cmdline_aliases => {I=>{}},
         },
 
         code_after_shebang => {
@@ -658,13 +659,13 @@ _
                             push @l, 'my $code = ', _deparse($alias_spec->{code}), '; ';
                             push @l, '$code->(\%_pci_args);';
                         } else {
-                            push @l, '$_pci_args{', $specmeta->{arg}, '} = $_[1];';
+                            push @l, '$_pci_args{\'', $specmeta->{arg}, '\'} = $_[1];';
                         }
                     } else {
                         if (($specmeta->{parsed}{type} // '') =~ /\@/) {
-                            push @l, 'if ($mentioned_args{', $specmeta->{arg}, '}++) { push @{ $_pci_args{', $specmeta->{arg}, '} }, $_[1] } else { $_pci_args{', $specmeta->{arg}, '} = [$_[1]] }';
+                            push @l, 'if ($mentioned_args{\'', $specmeta->{arg}, '\'}++) { push @{ $_pci_args{\'', $specmeta->{arg}, '\'} }, $_[1] } else { $_pci_args{\'', $specmeta->{arg}, '\'} = [$_[1]] }';
                         } else {
-                            push @l, '$_pci_args{', $specmeta->{arg}, '} = $_[1];';
+                            push @l, '$_pci_args{\'', $specmeta->{arg}, '\'} = $_[1];';
                         }
                     }
                     push @l, "\n";
@@ -841,7 +842,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.22 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-23.
+This document describes version 0.23 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-23.
 
 =head1 SYNOPSIS
 
@@ -867,23 +868,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                    Rate  run 1 (lite) run --version (lite)  -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.265+-0.0087/s            --               -60.5%     -82.8%         -88.7%                 -91.0%      -93.7% -97.5%
- run --version (lite)    33.616+-0.081/s 153.42+-0.63%                   --     -56.4%         -71.5%                 -77.2%      -84.0% -93.6%
- -c (lite)                  77.1+-0.17/s   481.3+-1.3%        129.37+-0.75%         --         -34.5%                 -47.7%      -63.2% -85.3%
- run 1 (inline)           117.79+-0.72/s     788+-5.5%          250.4+-2.3%  52.77+-1%             --                 -20.1%      -43.8% -77.5%
- run --version (inline)     147.5+-1.6/s     1012+-12%          338.7+-4.7% 91.3+-2.1%     25.2+-1.5%                     --      -29.7% -71.8%
- -c (inline)                209.7+-1.3/s   1480.8+-10%          523.8+-4.2%  172+-1.8%       78+-1.6%             42.2+-1.7%          -- -59.9%
- perl                       522.8+-1.7/s     3841+-13%         1455.1+-6.2%  578+-2.6%    343.8+-3.1%            254.5+-3.9% 149.3+-1.8%     --
+                                   Rate  run 1 (lite) run --version (lite)    -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           13.376+-0.011/s            --               -60.2%       -82.3%         -88.5%                 -90.1%      -91.0% -97.5%
+ run --version (lite)   33.641+-0.044/s 151.51+-0.39%                   --       -55.6%         -71.0%                 -75.0%      -77.4% -93.7%
+ -c (lite)                75.77+-0.16/s   466.5+-1.3%        125.23+-0.55%           --         -34.7%                 -43.7%      -49.2% -85.8%
+ run 1 (inline)          115.95+-0.63/s   766.9+-4.7%          244.7+-1.9% 53.03+-0.89%             --                 -13.9%      -22.3% -78.3%
+ run --version (inline)    134.7+-1.8/s      907+-13%          300.4+-5.4%   77.8+-2.4%     16.2+-1.7%                     --       -9.7% -74.8%
+ -c (inline)               149.1+-1.7/s     1015+-13%          343.3+-5.2%   96.8+-2.3%     28.6+-1.7%               10.7+-2%          -- -72.1%
+ perl                        535+-7.2/s     3899+-54%            1490+-21%    606+-9.6%    361.4+-6.7%            297.2+-7.5% 258.7+-6.4%     --
  
  Average times:
-   perl                  :     1.9128ms
-   -c (inline)           :     4.7687ms
-   run --version (inline):     6.7797ms
-   run 1 (inline)        :     8.4897ms
-   -c (lite)             :    12.9702ms
-   run --version (lite)  :    29.7477ms
-   run 1 (lite)          :    75.3864ms
+   perl                  :     1.8692ms
+   -c (inline)           :     6.7069ms
+   run --version (inline):     7.4239ms
+   run 1 (inline)        :     8.6244ms
+   -c (lite)             :    13.1978ms
+   run --version (lite)  :    29.7256ms
+   run 1 (lite)          :    74.7608ms
 
 =head1 FUNCTIONS
 
